### Features
* A ServiceExtension which adds cookie authentication.
* Middleware which adds authentication to the ApplicationBuilder.
* Log In and Log Out pages reference the host's Shared/_Layout.cshtml.
* A default Admin/Index page.
* A _SingleUserLoginPartial.cshtml.
* An optional password.
### Quick Start
1. Install KenHaggerty.Com.SingleUser.
1. Edit the host web app's Startup.cs.
1. Authorize the Admin folder.
1. Add the _SingleUserLoginPartial to the host's Shared/_Layout.cshtml's navbar.
1. Build, run, and test.
#### Host Startup.ConfigureServices
```c#
public void ConfigureServices(IServiceCollection services)
{
    services.AddRazorPages();    
    services.AddSingleUser();
}
```
##### AddSingleUser Implements:
```c#
services.AddAuthentication(CookieAuthenticationDefaults.AuthenticationScheme)
    .AddCookie(options =>
    {
        options.LoginPath = "/account/login";
        options.LogoutPath = "/account/logout";
        options.Cookie.SameSite = SameSiteMode.Strict;
        options.Cookie.SecurePolicy = CookieSecurePolicy.SameAsRequest;
        options.Cookie.IsEssential = true;
    });
```
#### Host Startup.Configure
```c#
public void Configure(IApplicationBuilder app, IWebHostEnvironment env)
{
    if (env.IsDevelopment())
    {
        app.UseDeveloperExceptionPage();
    }
    else
    {
        app.UseExceptionHandler("/Error");
        // The default HSTS value is 30 days. You may want to change this for production scenarios, see https://aka.ms/aspnetcore-hsts.
        app.UseHsts();
    }

    app.UseHttpsRedirection();
    app.UseStaticFiles();

    app.UseRouting();

    app.UseSingleUserMiddleware();

    app.UseAuthorization();

    app.UseEndpoints(endpoints =>
    {
        endpoints.MapRazorPages();
    });
}
```
##### UseSingleUserMiddleware Implements:
```c#
app.UseAuthentication();
```
#### Log In and Log Out Pages
The Log In and Log Out pages are in an Account folder/path. All package pages reference the host's Shared/_Layout.cshtml.
#### Default Admin/Index Page
The host needs to authorize the Admin folder.
```c#      
services.AddRazorPage(options => { options.Conventions.AuthorizeFolder("/Admin"); });
```
The default admin index page will be overridden by the host's Admin/Index page.
#### Host Shared/_Layout.cshtml
Insert _SingleUserLoginPartial into the host's navbar.
```xml      
<div class="navbar-collapse collapse d-sm-inline-flex flex-sm-row-reverse">
    <partial name="_SingleUserLoginPartial" />
    <ul class="navbar-nav flex-grow-1">
        <li class="nav-item">
            <a class="nav-link text-dark" asp-area="" asp-page="/Admin/Index">Admin</a>
        </li>
    </ul>
</div>
```
##### _SingleUserLoginPartial.cshtml Implements:
```xml      
<ul class="navbar-nav">
    @if (User.Identity.IsAuthenticated)
    {
        <li class="nav-item">
            <form class="form-inline" asp-page="/Account/LogOut" method="post">
                <button type="submit" class="nav-link text-dark btn btn-link pt-1">Log Out @User.Identity.Name</button>
            </form>
        </li>
    }
    else
    {
        <li class="nav-item">
            <a class="nav-link text-dark" asp-page="/Account/LogIn">Log In</a>
        </li>
    }
</ul>
```
#### Optional Password
A password is not required. For basic password support, add a SingleUserPassword key with your password to the host's appsettings.json's root.

[KenHaggerty.Com](https://kenhaggerty.com)